@@ -63,14 +63,9 @@ extractPrediction <- function(
           
           if(!is.null(testX) & !is.null(testY))
             {
-              if(models[[i]]$method %in% c("rpart", "treebag"))
-                {
-                  tempX <- testX
-                  tempY <- testY
-                } else {
-                  tempX <- testX[!hasNa,]
-                  tempY <- testY[!hasNa]         
-                }
+              if(!is.data.frame(testX)) testX <- as.data.frame(testX)
+              tempX <- testX
+              tempY <- testY
               tempX$.outcome <- NULL
               
               if(is.null(models[[i]]$preProcess))
@@ -101,14 +96,8 @@ extractPrediction <- function(
         }
       if(!is.null(unkX))
         {
-          if(models[[i]]$method %in% c("rpart", "treebag"))
-            {
-              tempX <- unkX
-            } else {
-              if(!is.data.frame(unkX)) unkX <- as.data.frame(unkX)
-              hasNa <- apply(unkX, 1, function(data) any(is.na(data)))         
-              tempX <- unkX[!hasNa,]
-            }
+          if(!is.data.frame(unkX)) unkX <- as.data.frame(unkX)
+          tempX <- unkX
           tempX$.outcome <- NULL
           
           if(is.null(models[[i]]$preProcess))
